!!$=head1 NAME
!!$
!!$Helocut - Helix Lowcut filter in 2-D
!!$
!!$=head1 SYNOPSIS
!!$
!!$Helocut < in.H helix=1 na=16 eps=0.1 > out.H
!!$
!!$=head1 DESCRIPTION
!!$
!!$Applies helix convolution with a low-cut factor, based on factoring the
!!$laplacian filter.  Also loops over n3.
!!$
!!$=head1 PARAMETERS
!!$
!!$=over 3
!!$
!!$=item from history
!!$
!!$B<integer> I<n1>, I<n2>
!!$
!!$=item from par
!!$
!!$B<logical> I<helix>=1 - if 0, apply the gradient filter on the 1st axis
!!$
!!$B<real> I<eps> - sets the lowcut frequency
!!$
!!$B<integer> I<na>=16 - filter size (half the number of nonzero coefficients)
!!$
!!$=back
!!$
!!$=head1 EXAMPLES
!!$
!!$F<gee/hlx/helocut90/>
!!$
!!$=head1 MODULES
!!$
!!$F<helicon.lop>, F<helocut.r90>
!!$
!!$=head1 SEA ALSO
!!$
!!$L<Helicon>, L<Wilson>
!!$
!!$=cut
!%
program Helc
  use helocut
  use helicon
  use sep

  implicit none
  integer                          :: na, stat, n1, n2, n12, i3, n3
  logical                          :: hel
  real                             :: eps
  real, dimension (:), allocatable :: pp, qq
  type( filter)                    :: aa

  call sep_init (SOURCE)
  call from_history (n1, n2, n3)
  call from_par ("eps", eps, 0.1)
  call from_par ("helix",hel,.true.)
  call from_par ("na", na, 16)
  call sep_close ()

  n12 = n1*n2
  allocate (pp(n12), qq(n12))

  if (hel) then
     call helocut_init (eps, n1, n2, na) 
     do i3=1,n3
        call sep_read ( pp)
	stat = helocut_lop (.false.,.false., pp, qq)
        call sep_write( qq)
	enddo
     call helocut_close ()
  else 
     call allocatehelix( aa, 1)
     aa%flt( 1) = -1.
     aa%lag( 1) =  1
     call helicon_init (aa) 
     do i3=1,n3
        call sep_read ( pp)
        stat = helicon_lop (.false.,.false., pp, qq)
        call sep_write( qq)
	enddo
     call deallocatehelix( aa)
  end if

  deallocate (pp, qq)
  call exit (0)
end program Helc
